@@ -6,12 +6,12 @@ from .blueprint import openapi_documentation
 
 
 @openapi_documentation.get("")
-def index():
+def get():
     """Get Open API UI page."""
     config = {
         "app_name": "OpenAPI UI",
         "dom_id": "#openapi-ui",
-        "url": url_for("openapi_documentation.configuration"),
+        "url": url_for("openapi_documentation.specification"),
         "layout": "StandaloneLayout",
         "deepLinking": True,
     }
